@@ -1,10 +1,10 @@
 plot.tunelocal<-
 function(x,...){
 #----------------------------plot tunelocal
-cat("From tunelocal: Convex hull for choosing the optimal model dimension -Chi2 criterion-\n\n")
+cat("From tunelocal: Convex hull for choosing the optimal model dimension -Goodness criterion-\n\n")
  #plot(x, type = "b")
 plot(x)  
-title(sub="Chi2 criterion")
+#title(sub="Chi2 criterion")
 #---
 #if (is.na(x2[1])==FALSE){
 #plot(x2, type = "b")
